#ifndef algorithmConditional_h
#define algorithmConditional_h

#include "Event/algorithmVI.h"
#include "Event/cutVI.h"

//! algorithm that runs only if a cut condition is fulfill
/*!
\algorithmConditional is an algorithm.<br>
\algorithmConditional runs its internal algorithm when a cut condition is
fulfill.
<ul>
	<li> the cut and the internal algorithm are indicates from a client
	with the methods: \c setCut() and \c setAlgorithm.
</ul>
*/
//--------------------------------
// JA Hernando, Santa Cruz, CA, 06/16/00
//--------------------------------

//################################
class algorithmConditional : public algorithmVI
//################################
{
public:

	//! default constructor - set the null the member variables
	algorithmConditional() {m_cut=0;m_alg=0;}
	//! default destructor
	~algorithmConditional() {};

	//! set the cut of the algorithm conditional
	virtual void setCut(cutVI* cut) {m_cut=cut;}
	//! set the algorithm
	virtual void setAlgorithm(algorithmVI* alg) {m_alg= alg;}

	//! initialize the algorithm only if the cut is fulfill
	virtual void initialize() {if (condition()) m_alg->initialize();}
	//! execute the algorithm only if the cut is fulfill
	virtual void execute()    {if (condition()) m_alg->execute();}
	//! finalize the algorithm only if the cut is fulfill
	virtual void finalize()   {if (condition()) m_alg->finalize();}

protected:

	//! returns true if the condition is fulfill
	virtual bool condition() {return m_cut->apply();}

private:

	//! pointer to the cut
	cutVI* m_cut;
	//! pointer to the algorithm
	algorithmVI* m_alg;
};
#endif