#ifndef centellaSys_h
#define centellaSys_h

class processManager;
class selectionManager;
class dataManager;

class optionManager;
class messageManager;

//-------------------------------
//! Creates the Centella System
/*! 
\e Centella System has the following managers:  dataManager, processManager, selectionManager, 
optionManager and messageManager. <br>
\e Managers are singletons. They can be invoqued using the static method \c instance(),
(i.e processManager::instance() returns a pointer to processManager).<br>
\e Managers: optionManager, and messageManager are <b> application independent </b>.
In priniple the <b> uer </b> does not need to modify them or implement any class.
 It could be that the user will create classes derived from serviceI, optionVI or messageVI and will need
to declare them to the servers of the managers. <br
\e Managers: dataManager, processManager and selectionManager, are <b> application dependent </b>.
The <b> users </b> should implement their algorithms, cuts and transient data classes,
 and add them into the managers. That force the user the derived his/her classes from
 the following base classes: algorithmVI, cutVI and trsDataVI. the detector geometry or the persistent
 data could force the <b> user </b> to make some modifications in the dataManager.
<ul>
	<li> the processManagers stores, serves and executes the system an application
	algorithms. All the algorithms lately inherits from the base class algorithmVI.
	<li> the selectionManager stores, servers and apply the system and application
	selections and cuts. All the cuts and selections lately inherits from the base class
	cutVI.
	<li> the dataManagers stores ans serves the data. The data is clasified into
	persistent and transient. The persistent data is left to the <b> user </b> to handle.
	The transient data inherits from the base class trsDataVI.
	the user should provide the converters from transient to persistent data and turn
	them into algorithms.
	<li> the optionManager allows to set options into classes. 
	Those classes should inherit from optionVI and should be declared into the server. 
	The options can be strings, doubles, integers, and booleans.
	<li> the messageManager defines an ostream for the system, and allows the classes
	to send messages to that ostream.
</ul>
*/
//----------------------------
// JA Hernando, Santa Cruz 02/15/00
//----------------------------
//############################
class centellaSys
//############################
{
public:

	//! constructor - create the managers
	centellaSys();
	//! destructor - delete the managers
	~centellaSys();

private:

	//! application independent messageManager
	messageManager*   m_messageManager;
	//! application independent optionManager
	optionManager*    m_optionManager;
	
	//! application dependent dataManager
	dataManager*        m_dataManager;
	//! application dependent processManager
	processManager*     m_processManager;
	//! application dependent selectionManager
	selectionManager* m_selectionManager;
};
#endif