//-----------------------------------------
//
//    Data Server
//
//-----------------------------------------

#ifndef dataEventServer_H
#define dataEventServer_H 1

#include "Event/trsDataVI.h"
#include "Event/serverVI.h"
#include "Event/serviceI.h"

//------------------------------------------
//! stores, servers, updates the EVENT transient data
/*! 
<ul>
	<li> The user should construct and add his/her event data classes in the userDataEvent class.
	<li> The user can add transient event data using the method \c addData().
	<li> The manager has a protected server with the event transient data.
	The data is served by dataManager via the method getData().
	</ul>
*/
//-----------------------------------------
// JA Hernando, Santa Cuz, CA 02/15/00
//-----------------------------------------
//#########################################
class dataEventServer : public serviceI
//#########################################
{
	/*! dataManager friend to acces the server of transient data*/
	friend class dataManager;

public:

	//! default constructor - it creates all the event data of the run
	dataEventServer();
	//! default constructor
	~dataEventServer(); 

	//! add data into the server
	virtual void addData(std::string name, trsDataVI* data);

	//! updates the data named data
	virtual void update(std::string name);

	//! write out the information of all the data classes
	virtual void writeOutServer() const {m_server->command("writeOut");}
	//! write out information of a given event data class
	virtual void writeOut(std::string name) const {m_server->get(name)->writeOut();}

	//! write out the information of the data
	virtual void writeOut() const;

protected:

	//! returns trsDataVI
	serverVI<trsDataVI>* server() {return m_server;}

	//! returns the trsDataVI associated with this name
	trsDataVI* getTrsData(std::string name) const;

private:

	//! pointer to the server with all the trsDataVI of type event
	serverVI<trsDataVI>* m_server;
};

#endif
