
#ifndef messageVI_h
#define messageVI_h

#include "Event/nameVI.h"
#include "Event/messageBase.h"

//------------------------------------
//! Interface class to the messageManager
/*! 
<ul>
	<li> The method \c message() allows the derived class to send messages (either strings, or 
	string + double values) to the messageManager.
	<li> It defines a LEVEL (from messageBase) indicating which is the level of
	information provided by the derived class. The \c acceptLevel() indicates when
	the level of the class is superior to the level of the messageManager.
	<li> The virtual method \c writeOut() is the place where the derived class should
	put the information that wants to write out. this method could/should be overwriten
	by the User.
	<li> The method \c setName() set the derived object into the server of messageManager,
	the object will be refered with its name. 
</ul>
*/
//-----------------------------------
// JA Hernando, Santa Cruz, CA, 05/15/00
//-----------------------------------
//########################
class messageVI : public nameVI
//########################
{
	friend class messageManager;

public:

	//! returns true is the info should be expresed
	/*! compare the level of the derived class with those one of the messageManager */
	bool acceptLevel() const;
	
	//! base virtual method to write information of the derived class via the messageManager
	virtual void writeOut() const;

protected:

	//! constructor - set the level to the lowest
	messageVI() {m_level = messageBase::DEBUG_HIGH;};
	//! destructor
	~messageVI() {}

	//! add this object it into the messageManager server with a given name
	virtual void setName(std::string name);

	//! sets the Level - make a conversion from string to enum LEVEL
	void setLevel(std::string lev) { m_level = messageBase::getLevel(lev);};
	//! return the level
	
	//! send string messages to the messageManager
	virtual void message(std::string message, std::string slevel = "") const ;
	//! send double value messages to the messageManager
	virtual void message(std::string message, double value, std::string slevel = "") const;

	//! returns the enum LEVEL of this class
	enum messageBase::LEVEL getLevel() const {return m_level;}

private:

	//! level of this class
	enum messageBase::LEVEL m_level;

};
#endif