#ifndef rHistoFolder_h
#define rHistoFolder_h

#include <string>

#include "Event/defineVI.h"
#include "Event/rHistoServer.h"

class TFile;

//-------------------------------------
//! base class to define, store and fill a group of root histograms and ntuples
/*!
<ul>
	<li> The \c setFile() methods allow to define a TFile where store in ROOT 
	the histograms. Note that every rHistoFolder should have a TFile root file
	defined in order to be able to store the histograms!. 
	<li> The derived class should implement the \c define() method to \b book the histograms and ntuples
	<li> The derived class should implement the \c fill() method to \b fill the histograms and ntuples
	<li> We use defineVI to call the \c define() method only ones. When
	an external user call \c fill() for the first time, the \c define() method
	is executed and the histograms/ntuples booked.
</ul>
*/
//----------------------------------
// JA Hernando, Santa Cruz, CA 05/16/00
//----------------------------------

//##################################
class rHistoFolder : public rHistoServer, public defineVI
//##################################
{
public:

	friend class rHistoFolderServer;

public:
	
	//! constructor
	rHistoFolder() {setDefine(false); m_RFile = 0;};
	//! destructor
	~rHistoFolder() {};

	//! return the pointer to the file where the histogram/ntuples are going to be stored
	TFile* getFile()    const {return m_RFile;}

	//! pure virtual method defines (book) histograms and ntuples
	virtual void define() = 0;
	//! A pure virtual method to fill the histograms and ntuples
	virtual void fill() = 0;

protected:

	//! set the root-file where the histogram/ntuples are stores
	/*! It allows derived classes to especify the root-file*/
	virtual void setFile(TFile* file) {m_RFile = file;}

private:

	//! pointer to the output root-file
	TFile* m_RFile;

};

#endif