#ifndef runEventAlg_h
#define runEventAlg_h

#include "Event/algorithmCommand.h"
#include "Event/defineVI.h"

#include "Event/cutVI.h"
#include "Event/algorithmVI.h"

//! An algorithm that runs all the algorithms needed to process one EVENT
/*!
\e runEventAlg is an algorithmVI that runs all the algorithms of one \b event.<br>
\e runEventAlg reads from presistency, process the event and write back
into persistency.
<ul>
	<li> It has two selection: \e "selRead" and \e "selWrite" that indicates if
	the event should be read and if the event should be write (save) in persistency
	after been processed.
	<li> It also has the system eventTask algorithm called \e "runEvent" that runs
	all the list of algorithms to be executed in the event.
	<li> The logic of the algorithm is implemented in the \c execute() method
	(have a look at the code).
</ul>
*/
//#####################################
class runEventAlg : public algorithmCommand, public defineVI
//#####################################
{
public:

	//! default constructor
	runEventAlg() {}
	//! defautl destrutor
	~runEventAlg() {}

	//! execute the algorithm
	virtual void execute();
	//! define the algorithm using other algorithms
	virtual void define();

private:

	//! cutVI should we read the next event?
	cutVI* m_cReadEvent;
	//! cutVI should we write this event?;
	cutVI* m_cWriteEvent;
	//! algorithmVI to read the event;
	algorithmVI* m_aReadEvent;
	//! algorithmVI to process the event; 
	algorithmVI* m_aProcessEvent;
	//! algorithmVI to write and event;
	algorithmVI* m_aWriteEvent;
	//! algorithmVI to skip and event
	algorithmVI* m_aSkipEvent;

};
#endif