#ifndef serverVI_h
#define serverVI_h

#include <vector>
#include <string>
//-------------------------
//! Template container class
/*!
\e serverVI stores objects accesible by index or by its name (string) <br>
\e serverVI executes commands to all its objects via the \c command() method.
The contained classes should therefore have defined this method.
<ul>
	<li> The server store POINTERS to the templates. It uses the method \c add() to
	add objects.
	<li> Every object should have a unique name. The server will refuse
	to add an object which name corresponds to another object already stored in the server,
	<li> the objects are accesible by their names or by they index via the \c get() method.
	It the object required is NOT in the server, the server returns a 0 pointer that
	mostlikely will break the program. 
	<li> via the \c search() method a client can ask if an object with that name is
	already in ther server.
	<li> it has the possibility of executing class methods viapassing then with
	the \c command() method.
	<li> Not possibility (yet) of removing objects from the server. DO NOT delete
	object that are in the server if the server is not destroyed or not used.
	<li> future plan: use a map<string,T> class as base class.
</ul>
*/	
//------------------------
// JA Hernando, Santa Cruz, CA, 05/15/00
//------------------------
//########################
template<class T> class serverVI 
//########################
{
public:

	
	//! default constructor
	serverVI() {m_names.clear();m_List.clear();}
	//! defualt destructor
	~serverVI() {}

	//! add a new element, with its name and pointer to the template class
	void add(std::string n, T* t) 
	{
		if (!search(n)) {
			m_names.push_back(n);
			m_List.push_back(t);
		} 
	}

	//! returns number of elements in to server
	int size() const {return num();}
	//! returns number of elements in the server
	int num() const {return (m_List.size() == m_names.size()? m_List.size(): 0);}
	//! add element

	//! no entries (no deletion of pointers)
	void clear() {m_names.clear();m_List.clear();}

	//! returns true if the object with name is in the server
	bool search(std::string name) const {
		for (int i = 0; i < m_List.size(); i++) {
			if (m_names[i] == name) return true;
		}
		return false;
	}

	//! returns the name of the object, (otherwise "EMPTY")
	std::string getName(T* t) const {
		for (int i = 0; i < m_List.size(); i++) {
			if (m_List[i] == t) return m_names[i];
		}
		return "EMPTY";
	}	

	//! returns the name of the i object (otherwise "EMPTY")
	std::string getName(int i) const {return ((i >=0 && i < num())? m_names[i]: "EMPTY");}

	//! returns the pointer to the object with name
	T* get(std::string name) const {
		for (int i = 0; i < m_List.size(); i++) {
			if (m_names[i] == name) return m_List[i];
		}
		return 0;
	}

	//! returns the pointer to the i element
	T* get(int i) const { return ((i >=0 && i < num())? m_List[i]: 0);}

	//! returns a string with the list of all the names in the server
	std::string nameList() const {
		std::string list = " " ;
		for (int i = 0; i < m_List.size(); i++) list = list+" in server : "+m_names[i]+ " \n ";
		return list;
	}	
	
	//! executed a command com defined in the template class to all the elements in server
	void command(std::string com) const {
		for (int i = 0; i < m_List.size(); i++) m_List[i]->command(com);
	}

private:

	std::vector<std::string> m_names;
	std::vector<T*> m_List;

};
#endif